@@ -320,13 +320,11 @@ void	HyperTreeDraw::Draw(HyperDocument &html, WINDOW *pad)
 		time_t scanTime = GetScanTime();
 		struct tm *scanTime2 = localtime(&scanTime);
 
-		ostrstream bufstr;
+		gtstream bufstr;
 		gtout(bufstr, _("%$ %$   Last scan: %$"))
 		     << progName << version
 		     << my_strftime(_("%b %e  %H:%M"), scanTime2);
-		bufstr << ends;
 		html.DrawSetTitle(bufstr.str());
-		bufstr.freeze(false);
 	}
 
 	bool	first = true;
@@ -476,11 +474,9 @@ void	HyperListDraw::Draw(HyperDocument &html, WINDOW *pad)
 
 	if (!pad) {
 				// Determine document size
-//		ostrstream bufstr;
+//		gtstream bufstr;
 //		gtout(bufstr, "echo %$ %$ > xx") << match_list.size() << 3+numDigit+max_length;
-//		bufstr << ends;
 //		system(bufstr.str());
-//		bufstr.freeze(false);
 
 		html.DrawSetSize(match_list.size(), 3+numDigit+max_length);
 	}
@@ -495,13 +491,11 @@ void	HyperListDraw::Draw(HyperDocument &html, WINDOW *pad)
 		time_t scanTime = GetScanTime();
 		struct tm *scanTime2 = localtime(&scanTime);
 
-		ostrstream bufstr;
+		gtstream bufstr;
 		gtout(bufstr, _("%$ %$   Found: %$   Last scan: %$"))
 		     << progName << version << match_list.size()
 		     << my_strftime(_("%b %e  %H:%M"), scanTime2);
-		bufstr << ends;
 		html.DrawSetTitle(bufstr.str());
-		bufstr.freeze(false);
 
 		size_t	index = 1;
 		for (list<MatchInfo>::iterator iter = match_list.begin();
@@ -749,7 +743,7 @@ FindDirInfo *FindDir(const string &str, bool honor_cfg, bool change_top,
 		return 0;
 }
 
-FindDirInfo *FindDir(const string &str, bool honor_cfg, bool change = true)
+FindDirInfo *FindDir(const string &str, bool honor_cfg, bool change)
 {
 	return FindDir(str, honor_cfg, change, change);
 }
