@@ -1,6 +1,6 @@
 /*
 	list.h		Linked-List Functions Header
-	Copyright (c) 1996-8,2000,2001 Kriang Lerdsuwanakij
+	Copyright (c) 1996-8,2000,2001,2002 Kriang Lerdsuwanakij
 	email:		lerdsuwa@users.sourceforge.net
 
 	This program is free software; you can redistribute it and/or modify
@@ -33,9 +33,9 @@ USING_NAMESPACE_STD;
 *************************************************************************/
 
 template <class T> class sptr {
-		T * const	ptr;
-		size_t * const	count_ptr;
-		bool * const	own;
+		T *	ptr;
+		size_t *	count_ptr;
+		bool *	own;
 	public:
 				// Create new smart pointer from scratch
 				// ptr_ is now own by sptr
@@ -69,6 +69,7 @@ template <class T> class sptr {
 			count_ptr = s.count_ptr;
 			own = s.own;
 			++*count_ptr;
+			return *this;
 		}
 
 				// Release ptr from our pointer management
@@ -101,9 +102,9 @@ template <class T> bool operator < (const sptr<T> &s1, const sptr<T> &s2)
 *************************************************************************/
 
 template <class T> class saptr {
-		T * const	ptr;
-		size_t * const	count_ptr;
-		bool * const	own;
+		T *	ptr;
+		size_t *	count_ptr;
+		bool *	own;
 	public:
 				// Create new smart pointer from scratch
 				// ptr_ is now own by saptr
